@@ -14,8 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+
+from collections.abc import Mapping, Sequence
 from io import IOBase
-from typing import List, Mapping, Optional
+from typing import Optional
 
 from selenium.types import SubprocessStdAlias
 from selenium.webdriver.common import service
@@ -25,29 +27,35 @@ class ChromiumService(service.Service):
     """A Service class that is responsible for the starting and stopping the
     WebDriver instance of the ChromiumDriver.
 
-    :param executable_path: install path of the executable.
-    :param port: Port for the service to run on, defaults to 0 where the operating system will decide.
-    :param service_args: (Optional) List of args to be passed to the subprocess when launching the executable.
-    :param log_output: (Optional) int representation of STDOUT/DEVNULL, any IO instance or String path to file.
-    :param env: (Optional) Mapping of environment variables for the new process, defaults to `os.environ`.
-    :param driver_path_env_key: (Optional) Environment variable to use to get the path to the driver executable.
+    Args:
+        executable_path: Install path of the executable.
+        port: Port for the service to run on, defaults to 0 where the operating
+            system will decide.
+        service_args: (Optional) Sequence of args to be passed to the subprocess
+            when launching the executable.
+        log_output: (Optional) int representation of STDOUT/DEVNULL, any IO
+            instance or String path to file.
+        env: (Optional) Mapping of environment variables for the new process,
+            defaults to `os.environ`.
+        driver_path_env_key: (Optional) Environment variable to use to get the
+            path to the driver executable.
     """
 
     def __init__(
         self,
         executable_path: Optional[str] = None,
         port: int = 0,
-        service_args: Optional[List[str]] = None,
+        service_args: Optional[Sequence[str]] = None,
         log_output: Optional[SubprocessStdAlias] = None,
         env: Optional[Mapping[str, str]] = None,
         driver_path_env_key: Optional[str] = None,
         **kwargs,
     ) -> None:
-        self.service_args = service_args or []
+        self._service_args = list(service_args or [])
         driver_path_env_key = driver_path_env_key or "SE_CHROMEDRIVER"
 
         if isinstance(log_output, str):
-            self.service_args.append(f"--log-path={log_output}")
+            self._service_args.append(f"--log-path={log_output}")
             self.log_output: Optional[IOBase] = None
         elif isinstance(log_output, IOBase):
             self.log_output = log_output
@@ -63,5 +71,15 @@ class ChromiumService(service.Service):
             **kwargs,
         )
 
-    def command_line_args(self) -> List[str]:
-        return [f"--port={self.port}"] + self.service_args
+    def command_line_args(self) -> list[str]:
+        return [f"--port={self.port}"] + self._service_args
+
+    @property
+    def service_args(self) -> Sequence[str]:
+        return self._service_args
+
+    @service_args.setter
+    def service_args(self, value: Sequence[str]):
+        if isinstance(value, str) or not isinstance(value, Sequence):
+            raise TypeError("service_args must be a sequence")
+        self._service_args = list(value)
