@@ -22,7 +22,7 @@ import subprocess
 import sys
 import sysconfig
 from pathlib import Path
-from typing import List, Optional
+from typing import Optional
 
 from selenium.common import WebDriverException
 
@@ -35,12 +35,14 @@ class SeleniumManager:
     This implementation is still in beta, and may change.
     """
 
-    def binary_paths(self, args: List) -> dict:
+    def binary_paths(self, args: list) -> dict:
         """Determines the locations of the requested assets.
 
-        :Args:
-         - args: the commands to send to the selenium manager binary.
-        :Returns: dictionary of assets and their path
+        Args:
+            args: the commands to send to the selenium manager binary.
+
+        Returns:
+            Dictionary of assets and their path.
         """
 
         args = [str(self._get_binary())] + args
@@ -57,9 +59,11 @@ class SeleniumManager:
     def _get_binary() -> Path:
         """Determines the path of the correct Selenium Manager binary.
 
-        :Returns: The Selenium Manager executable location
+        Returns:
+            The Selenium Manager executable location.
 
-        :Raises: WebDriverException if the platform is unsupported
+        Raises:
+            WebDriverException: If the platform is unsupported.
         """
 
         compiled_path = Path(__file__).parent.joinpath("selenium-manager")
@@ -102,12 +106,14 @@ class SeleniumManager:
         return path
 
     @staticmethod
-    def _run(args: List[str]) -> dict:
+    def _run(args: list[str]) -> dict:
         """Executes the Selenium Manager Binary.
 
-        :Args:
-         - args: the components of the command being executed.
-        :Returns: The log string containing the driver location.
+        Args:
+            args: the components of the command being executed.
+
+        Returns:
+            The log string containing the driver location.
         """
         command = " ".join(args)
         logger.debug("Executing process: %s", command)
@@ -131,7 +137,7 @@ class SeleniumManager:
         return result
 
     @staticmethod
-    def _process_logs(log_items: List[dict]):
+    def _process_logs(log_items: list[dict]):
         for item in log_items:
             if item["level"] == "WARN":
                 logger.warning(item["message"])
